function DoubleMeshPlot(figureNr,OnstimOneye,OnstimOffeye,OnstimOneyeOndir,Onstim,BistimLeye,BistimReye,...
    BistimOneyeOndir,Bistim,obs)
%%%%-------------------------------------------%%%%
% figureNr = number of figure used to display results
% OnstimOneye = position trace of on eye during on monocular phase
% OnstimOffeye = position trace of off eye during on monocular phase
% OnstimOneyeOndir = index vector for on eye during on monocular phase in on direction
% Onstim = DFF during on eye stimulation
% BistimLeye = Left eye position during binocular stimulation
% BistimReye = Right eye position during binocular stimulation
% BistimOneyeOndir = index vector for on eye during binocular stimulation on direction 
% Bistim = DFF during binocular stimulation
% obs = celltype identifier
%%%%-------------------------------------------%%%%

figure(figureNr)

if strcmp(obs,'Lstim') 
    [MonoOnstimOndirmat]=createMonoBinoComp(OnstimOneye,OnstimOffeye,OnstimOneyeOndir,true(300,1),Onstim); 
     Bistimsize=size(Bistim,2);
    [BinoLdirmat]=createMonoBinoComp(BistimLeye,BistimReye,BistimOneyeOndir,true(Bistimsize,1),Bistim);
elseif strcmp(obs,'Rstim')
     [MonoOnstimOndirmat]=createMonoBinoComp(OnstimOffeye,OnstimOneye,true(300,1),OnstimOneyeOndir,Onstim); 
     Bistimsize=size(Bistim,2);
     [BinoLdirmat]=createMonoBinoComp(BistimLeye,BistimReye,true(Bistimsize,1),BistimOneyeOndir,Bistim); 
else
    FORCEDERROR
end

% plot
plotOnstimOndir=vertcat(MonoOnstimOndirmat,BinoLdirmat); %one matrix mono is above Bino below
handlefig=imagesc(1:60,1:120,plotOnstimOndir);
hold on
line([0 60],[60.5 60.5],'Color','k','LineWidth',2)
set(handlefig,'alphadata',~isnan(plotOnstimOndir))  
set(gca,'YTick',[0.5,15.5,30.5,45.5,60.5,75.5,90.5,105.5,120.5])
set(gca,'YTicklabel',{'30','15','monocular stimulation      0','-15','+/- 30','15','binocular stimulation      0','-15','-30',})
set(gca,'XTick',[0.5,15.5,30.5,45.5,60.5])
set(gca,'XTicklabel',{'-30','-15','0','15','30'})
ylabel('left eye')
xlabel('right eye')
title(strcat('comparison for ',{' '},obs))
colorbar
grid on

end % function end

